==> haskell-lsp-test-0.14.0.0-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.14.0.0
visibility:           public
id:                   lsp-test-0.14.0.0-1okwygM0sWIKDBTBA7ZUvy
key:                  lsp-test-0.14.0.0-1okwygM0sWIKDBTBA7ZUvy
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire, and @Language.LSP.Test@ can replay captured sessions from
    <haskell-lsp https://hackage.haskell.org/package/haskell-lsp>.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  3b705f0f89bc74d1986ff9477c3c6b72
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.2.0.0-G18BczNZ0nd6xEr0sTdQae:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.2.0.0-G18BczNZ0nd6xEr0sTdQae:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.0.1/site-local/lsp-test-0.14.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/lsp-test-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/lsp-test-0.14.0.0
hs-libraries:         HSlsp-test-0.14.0.0-1okwygM0sWIKDBTBA7ZUvy
depends:
    Diff-0.4.0-F7vyJzYzam9CwrUJdg8bD2
    Glob-0.10.1-4n8uI5fOteuBazOEt4V4ba
    aeson-1.5.6.0-HjRPlMbeXBZ4yuplu15455
    aeson-pretty-0.8.8-1eAuJOWyUl9x6mQ6Ia7UU
    ansi-terminal-0.11-AWG4ISlY8CcEJlJfIhaQcb
    async-2.2.3-KG7Du60y7DvAqBDAYoSjqL base-4.15.0.0
    bytestring-0.10.12.1 conduit-1.3.4.1-APoT7S8i9fNAuDbLjFbyiG
    conduit-parse-0.2.1.0-CJRan7or5iF3yyLVCKcu1D containers-0.6.4.1
    data-default-0.7.1.1-8aGzV3AyDr077p6b91gXPe directory-1.3.6.1
    filepath-1.4.2.1 lens-5.0.1-KAh7DAnq23eK3Mb3yHYdKP
    lsp-types-1.2.0.0-G18BczNZ0nd6xEr0sTdQae mtl-2.2.2
    parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6 process-1.6.11.0
    some-1.0.3-7sghqqTkEQg7XqQ206Tg1F text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.14.0-Wie4T3gD5k18ShmuaDNll

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-test-0.14.0.0-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp-test
version:              0.14.0.0
visibility:           public
id:                   lsp-test-0.14.0.0-JAQQcQTD6xW23Ui0KXKhQy
key:                  lsp-test-0.14.0.0-JAQQcQTD6xW23Ui0KXKhQy
license:              BSD-3-Clause
copyright:            2021 Luke Lau
maintainer:           luke_lau@icloud.com
author:               Luke Lau
homepage:
    https://github.com/haskell/lsp/blob/master/lsp-test/README.md

synopsis:             Functional test framework for LSP servers.
description:
    A test framework for writing tests against
    <https://microsoft.github.io/language-server-protocol/ Language Server Protocol servers>.
    @Language.LSP.Test@ launches your server as a subprocess and allows you to simulate a session
    down to the wire, and @Language.LSP.Test@ can replay captured sessions from
    <haskell-lsp https://hackage.haskell.org/package/haskell-lsp>.
    To see examples of it in action, check out <https://github.com/haskell/haskell-ide-engine haskell-ide-engine>,
    <https://github.com/haskell/haskell-language-server haskell-language-server> and
    <https://github.com/digital-asset/ghcide ghcide>.

category:             Testing
abi:                  ef36f00a937351fee24a9053295089e4
exposed:              True
exposed-modules:
    Control.Applicative.Combinators from parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6:Control.Applicative.Combinators,
    Language.LSP.Test,
    Language.LSP.Types from lsp-types-1.2.0.0-G18BczNZ0nd6xEr0sTdQae:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.2.0.0-G18BczNZ0nd6xEr0sTdQae:Language.LSP.Types.Capabilities

hidden-modules:
    Language.LSP.Test.Compat Language.LSP.Test.Decoding
    Language.LSP.Test.Exceptions Language.LSP.Test.Files
    Language.LSP.Test.Parsing Language.LSP.Test.Server
    Language.LSP.Test.Session

import-dirs:          /usr/lib/ghc-9.0.1/site-local/lsp-test-0.14.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/lsp-test-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/lsp-test-0.14.0.0
hs-libraries:         HSlsp-test-0.14.0.0-JAQQcQTD6xW23Ui0KXKhQy
depends:
    Diff-0.4.0-F7vyJzYzam9CwrUJdg8bD2
    Glob-0.10.1-4n8uI5fOteuBazOEt4V4ba
    aeson-1.5.6.0-HjRPlMbeXBZ4yuplu15455
    aeson-pretty-0.8.8-1eAuJOWyUl9x6mQ6Ia7UU
    ansi-terminal-0.11-AWG4ISlY8CcEJlJfIhaQcb
    async-2.2.3-KG7Du60y7DvAqBDAYoSjqL base-4.15.0.0
    bytestring-0.10.12.1 conduit-1.3.4.2-3a4oLt2zoluJkPoJvBjFCf
    conduit-parse-0.2.1.0-8uPXOWhcOlyCygJFL6hMAc containers-0.6.4.1
    data-default-0.7.1.1-8aGzV3AyDr077p6b91gXPe directory-1.3.6.1
    filepath-1.4.2.1 lens-5.0.1-KAh7DAnq23eK3Mb3yHYdKP
    lsp-types-1.2.0.0-G18BczNZ0nd6xEr0sTdQae mtl-2.2.2
    parser-combinators-1.3.0-5jHqYWwdpCqFWQLuYLRvi6 process-1.6.11.0
    some-1.0.3-7sghqqTkEQg7XqQ206Tg1F text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 unix-2.7.2.2
    unordered-containers-0.2.14.0-Wie4T3gD5k18ShmuaDNll

haddock-interfaces:   /usr/share/doc/haskell-lsp-test/html/lsp-test.haddock
haddock-html:         /usr/share/doc/haskell-lsp-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
